# Changelog

## Unreleased

## 1.8.0

* New function for removing files

## 1.7.0

* New distance segmentation function

## 1.6.1

* New dataset generate function with synthetic liver and portal vein
* Rotation works now with interpolation order = 1

## 1.5.2

* Test and first development on File System Browser

## 1.5.1

* Logger for `dicom_expected` flag

## 1.5.0

* Added `dicom_expected` flag to prevent warning

## 1.4.4

* Directory information is returned in `pandas` dataframe
* New sample generator - face

## 1.4.3

* Fixed warnings 
* Updated requirements

## 1.4.0

* Datasets update
* New pklz write test
* Fixed SimpleITK version issues

## 1.3.49

* Datasets moved to other server

## 1.3.48

* Filter doubled files

## 1.3.47

* Memory error fixed

## 1.3.44 2018-05-14

* PyQt4 QString compatibility with python 2 and python 3

## 1.3.43

* Better code climate with PEP8 fixes

## 1.3.40

* GUI Qt4 bytes type compatibility with python 2 and python 3

## 1.3.38

* New download function for datasets

## 1.3.36

* Object pickle algorithm compatible with python 2 and python 3

